<?php
/**
 * @file
 * Template.php file for the preprocessors and the likes.
 */

/**
 * Include common functions used throughout the theme.
 */
include_once dirname(__FILE__) . '/theme_overrides/form.inc';
include_once dirname(__FILE__) . '/theme_overrides/menu.inc';
include_once dirname(__FILE__) . '/theme_overrides/theme.inc';
include_once dirname(__FILE__) . '/theme_overrides/comments.inc';

/**
 * Implements template_preprocess_html().
 */
function bassline_preprocess_html(&$vars) {
  // Add mobile meta tags.
  $mobile_meta = array(
    '#tag' => 'meta',
    '#attributes' => array(
      'name' => 'viewport',
      'content' => 'width=device-width, initial-scale=1, maximum-scale=1'
    )
  );
  drupal_add_html_head($mobile_meta, 'bassline_mobile_meta');
}

/**
 * Implements template_preprocess_node().
 */
function bassline_preprocess_node(&$vars) {
  // Add suggestions to allow templates to target specific content types and view modes.
  $vars['theme_hook_suggestions'][] = 'node__' . $vars['type'] . '__' . $vars['view_mode'];

  // Add classes based on node status.
  if ($vars['promote']) {
    $vars['classes_array'][] = 'promoted';
  }
  if ($vars['sticky']) {
    $vars['classes_array'][] = 'sticky';
  }
  if ($vars['status'] == "0") {
    $vars['classes_array'][] = 'unpublished';
  }
}

/**
 * Implements hook_css_alter().
 *
 * Remove default drupal styles and some common contrib styles.
 */
function bassline_css_alter(&$css) {
  // Drupal core stylesheets.
  // Aggregator.
  if (module_exists('aggregator')) {
    unset($css['modules/aggregator/aggregator.css']);
  }
  // Book.
  if (module_exists('book')) {
    unset($css['modules/book/book.css']);
  }
  // Comment.
  if (module_exists('comment')) {
    unset($css['modules/comment/comment.css']);
  }
  // Forum.
  if (module_exists('forum')) {
    unset($css['modules/forum/forum.css']);
  }
  // Poll.
  if (module_exists('poll')) {
    unset($css['modules/poll/poll.css']);
  }
  // Search.
  if (module_exists('search')) {
    unset($css['modules/search/search.css']);
  }
  // Field.
  unset($css['modules/field/theme/field.css']);
  // Node.
  unset($css['modules/node/node.css']);
  // System.
  unset($css['modules/system/system.menus.css']);
  unset($css['modules/system/system.theme.css']);
  unset($css['modules/system/system.base.css']);
  unset($css['modules/system/system.messages.css']);
  // User.
  unset($css['modules/user/user.css']);

  // Contrib stylesheets.
  // Views.
  if (module_exists('views')) {
    $views = drupal_get_path('module', 'views');
    unset($css[$views . '/css/views.css']);
  }
  // Ctools.
  if (module_exists('ctools')) {
    $ctools = drupal_get_path('module', 'ctools');
    unset($css[$ctools . '/css/ctools.css']);
    unset($css[$ctools . '/css/modal.css']);
  }
}
